@@ -5,7 +5,7 @@
     utils::globalVariables(
       c("value", "variable", "word_count", "w",
         "attrib", "feature", "id", "i", "wLex",
-        "wFeat", "wTime", "x", "identifier")
+        "wFeat", "wTime", "x", "identifier", "lag")
     )
   invisible()
 }
