@@ -22,13 +22,13 @@ sentimentList <- list(
   s1 = compute_sentiment(quanteda::texts(corpus), lex, how = "counts"),
   s2 = compute_sentiment(quanteda::texts(corpus), lex[1:3], how = "counts"),
   s3 = compute_sentiment(quanteda::texts(corpus), lex, how = "proportional"),
-  s4 = compute_sentiment(quanteda::texts(corpus), lex, how = "proportionalPol", nCore = 2),
+  s4 = compute_sentiment(quanteda::texts(corpus), lex, how = "proportionalPol"),
   s5 = compute_sentiment(quanteda::corpus(usnews[1:250, "texts"]), lex, how = "counts"),
   s6 = compute_sentiment(quanteda::corpus(usnews[1:250, c("texts", "wsj", "economy")], text_field = "texts"),
                          lex, how = "counts"),
   s7 = compute_sentiment(corpus, lex, how = "counts"),
   s8 = compute_sentiment(quanteda::texts(corpus), lexSplit, how = "counts"),
-  s9 = compute_sentiment(quanteda::texts(corpus), lex, how = "proportionalPol", nCore = 1),
+  # s9 = compute_sentiment(quanteda::texts(corpus), lex, how = "proportionalPol", nCore = 2),
   s10 = compute_sentiment(quanteda::texts(corpus), lexClust, how = "counts"),
   s11 = compute_sentiment(corpus, lexClust, how = "proportional"),
   s12 = compute_sentiment(quanteda::texts(corpus), lexClust, how = "proportionalPol")
@@ -41,7 +41,7 @@ test_that("Agreement between sentiment scores across input objects", {
                                                                == sentimentList$s1$sentiment$word_count)))))
   expect_true(all(sentimentList$s8[, c("GI_en_POS", "LM_en_POS", "HENRY_en_POS")] >= 0))
   expect_true(all(sentimentList$s8[, c("GI_en_NEG", "LM_en_NEG", "HENRY_en_NEG")] <= 0))
-  expect_true(all(sentimentList$s4 == sentimentList$s9))
+  # expect_true(all(sentimentList$s4 == sentimentList$s9))
   expect_equivalent(sentimentList$s1[, c("GI_en", "LM_en", "HENRY_en")],
                     sentimentList$s5[, c("GI_en", "LM_en", "HENRY_en")])
   expect_equivalent(sentimentList$s6[, -c(1:2)],
